==> aws-java-sdk-1.7.1-sources.jar: com/amazonaws/services/support/model/transform/CommunicationJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.support.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.support.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Communication JSON Unmarshaller
 */
public class CommunicationJsonUnmarshaller implements Unmarshaller<Communication, JsonUnmarshallerContext> {

    public Communication unmarshall(JsonUnmarshallerContext context) throws Exception {
        Communication communication = new Communication();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("caseId", targetDepth)) {
                    context.nextToken();
                    communication.setCaseId(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("body", targetDepth)) {
                    context.nextToken();
                    communication.setBody(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("submittedBy", targetDepth)) {
                    context.nextToken();
                    communication.setSubmittedBy(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("timeCreated", targetDepth)) {
                    context.nextToken();
                    communication.setTimeCreated(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return communication;
    }

    private static CommunicationJsonUnmarshaller instance;
    public static CommunicationJsonUnmarshaller getInstance() {
        if (instance == null) instance = new CommunicationJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.8.9.1-sources.jar: com/amazonaws/services/support/model/transform/CommunicationJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.support.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.support.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Communication JSON Unmarshaller
 */
public class CommunicationJsonUnmarshaller implements Unmarshaller<Communication, JsonUnmarshallerContext> {

    public Communication unmarshall(JsonUnmarshallerContext context) throws Exception {
        Communication communication = new Communication();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("caseId", targetDepth)) {
                    context.nextToken();
                    communication.setCaseId(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("body", targetDepth)) {
                    context.nextToken();
                    communication.setBody(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("submittedBy", targetDepth)) {
                    context.nextToken();
                    communication.setSubmittedBy(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("timeCreated", targetDepth)) {
                    context.nextToken();
                    communication.setTimeCreated(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("attachmentSet", targetDepth)) {
                    context.nextToken();
                    communication.setAttachmentSet(new ListUnmarshaller<AttachmentDetails>(AttachmentDetailsJsonUnmarshaller.getInstance()).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return communication;
    }

    private static CommunicationJsonUnmarshaller instance;
    public static CommunicationJsonUnmarshaller getInstance() {
        if (instance == null) instance = new CommunicationJsonUnmarshaller();
        return instance;
    }
}
